@@ -6,6 +6,8 @@ from django.contrib.auth.decorators import login_required
 # Create your views here.
 @login_required
 def index(request):
-    return render(request, 'magplan/sections/index.html', {
-        'sections': Section.objects.order_by('sort').all()
-    })
+    return render(
+        request,
+        "magplan/sections/index.html",
+        {"sections": Section.objects.order_by("sort").all()},
+    )
